@@ -4,7 +4,7 @@ $serv = new swoole_server("0.0.0.0", 9501, SWOOLE_BASE, SWOOLE_SOCK_TCP | SWOOLE
 $key_dir = dirname(dirname(__DIR__)).'/tests/ssl';
 
 // $port2 = $serv->addlistener('0.0.0.0', 9502, SWOOLE_SOCK_TCP);
-// $port2->on('receive', function($serv, $fd, $from_id, $data){
+// $port2->on('receive', function($serv, $fd, $reactor_id, $data){
 //     echo "port2: ".$data."\n";
 // });
 
@@ -18,19 +18,19 @@ $serv->set(array(
     'ssl_verify_depth' => 10,
 ));
 
-$serv->on('connect', function (swoole_server $serv, $fd, $from_id){
-	echo "[#".posix_getpid()."]\tClient@[$fd:$from_id]: Connect.\n";
+$serv->on('connect', function (swoole_server $serv, $fd, $reactor_id){
+	echo "[#".posix_getpid()."]\tClient@[$fd:$reactor_id]: Connect.\n";
     $info = $serv->getClientInfo($fd);
     var_dump($info);
 });
 
-$serv->on('receive', function (swoole_server $serv, $fd, $from_id, $data) {
+$serv->on('receive', function (swoole_server $serv, $fd, $reactor_id, $data) {
 	echo "[#".posix_getpid()."]\tClient[$fd]: $data\n";
 	$serv->send($fd, "Swoole: $data\n");
 });
 
-$serv->on('close', function ($serv, $fd, $from_id) {
-	echo "[#".posix_getpid()."]\tClient@[$fd:$from_id]: Close.\n";
+$serv->on('close', function ($serv, $fd, $reactor_id) {
+	echo "[#".posix_getpid()."]\tClient@[$fd:$reactor_id]: Close.\n";
 });
 
 $serv->start();
