@@ -76,6 +76,7 @@ enum swErrorCode {
     SW_ERROR_PACKAGE_LENGTH_TOO_LARGE = 1201,
     SW_ERROR_PACKAGE_LENGTH_NOT_FOUND,
     SW_ERROR_DATA_LENGTH_TOO_LARGE,
+    SW_ERROR_PACKAGE_MALFORMED_DATA,
 
     /**
      * task error
@@ -129,6 +130,8 @@ enum swErrorCode {
     SW_ERROR_WEBSOCKET_UNCONNECTED,
     SW_ERROR_WEBSOCKET_HANDSHAKE_FAILED,
     SW_ERROR_WEBSOCKET_PACK_FAILED,
+    SW_ERROR_WEBSOCKET_UNPACK_FAILED,
+    SW_ERROR_WEBSOCKET_INCOMPLETE_PACKET,
 
     /**
      * server global error
