@@ -31,21 +31,31 @@ void Channel::timer_callback(Timer *timer, TimerNode *tnode) {
     msg->co->resume();
 }
 
-void Channel::yield(enum opcode type) {
+void Channel::yield(enum Opcode type) {
     Coroutine *co = Coroutine::get_current_safe();
     if (type == PRODUCER) {
         producer_queue.push_back(co);
-        swTraceLog(SW_TRACE_CHANNEL, "producer cid=%ld", co->get_cid());
+        swoole_trace_log(SW_TRACE_CHANNEL, "producer cid=%ld", co->get_cid());
     } else {
         consumer_queue.push_back(co);
-        swTraceLog(SW_TRACE_CHANNEL, "consumer cid=%ld", co->get_cid());
+        swoole_trace_log(SW_TRACE_CHANNEL, "consumer cid=%ld", co->get_cid());
     }
-    co->yield();
+    Coroutine::CancelFunc cancel_fn = [this, type](Coroutine *co) {
+        if (type == CONSUMER) {
+            consumer_remove(co);
+        } else {
+            producer_remove(co);
+        }
+        co->resume();
+        return true;
+    };
+    co->yield(&cancel_fn);
 }
 
 void *Channel::pop(double timeout) {
     Coroutine *current_co = Coroutine::get_current_safe();
     if (closed && is_empty()) {
+        error_ = ERROR_CLOSED;
         return nullptr;
     }
     if (is_empty() || !consumer_queue.empty()) {
@@ -65,7 +75,16 @@ void *Channel::pop(double timeout) {
         if (msg.timer) {
             swoole_timer_del(msg.timer);
         }
-        if (msg.error || (closed && is_empty())) {
+        if (current_co->is_canceled()) {
+            error_ = ERROR_CANCELED;
+            return nullptr;
+        }
+        if (msg.error) {
+            error_ = ERROR_TIMEOUT;
+            return nullptr;
+        }
+        if (closed && is_empty()) {
+            error_ = ERROR_CLOSED;
             return nullptr;
         }
     }
@@ -87,6 +106,7 @@ void *Channel::pop(double timeout) {
 bool Channel::push(void *data, double timeout) {
     Coroutine *current_co = Coroutine::get_current_safe();
     if (closed) {
+        error_ = ERROR_CLOSED;
         return false;
     }
     if (is_full() || !producer_queue.empty()) {
@@ -106,7 +126,16 @@ bool Channel::push(void *data, double timeout) {
         if (msg.timer) {
             swoole_timer_del(msg.timer);
         }
-        if (msg.error || closed) {
+        if (current_co->is_canceled()) {
+            error_ = ERROR_CANCELED;
+            return false;
+        }
+        if (msg.error) {
+            error_ = ERROR_TIMEOUT;
+            return false;
+        }
+        if (closed) {
+            error_ = ERROR_CLOSED;
             return false;
         }
     }
@@ -114,7 +143,7 @@ bool Channel::push(void *data, double timeout) {
      * push data
      */
     data_queue.push(data);
-    swTraceLog(SW_TRACE_CHANNEL, "push data to channel, count=%ld", length());
+    swoole_trace_log(SW_TRACE_CHANNEL, "push data to channel, count=%ld", length());
     /**
      * notify consumer
      */
@@ -129,7 +158,7 @@ bool Channel::close() {
     if (closed) {
         return false;
     }
-    swTraceLog(SW_TRACE_CHANNEL, "channel closed");
+    swoole_trace_log(SW_TRACE_CHANNEL, "channel closed");
     closed = true;
     while (!producer_queue.empty()) {
         Coroutine *co = pop_coroutine(PRODUCER);
